if (Test-Path env:COMSPEC) {
    $Env:YARP_DATA_DIRS+=";$(Join-Path -Path $Env:CONDA_PREFIX -ChildPath Library\share\iCub)"
    $Env:ROS_PACKAGE_PATH+=";$(Join-Path -Path $Env:CONDA_PREFIX -ChildPath Library\share)"
    $Env:AMENT_PREFIX_PATH+=";$(Join-Path -Path $Env:CONDA_PREFIX -ChildPath Library)"
}
else {
    $Env:YARP_DATA_DIRS+=";$(Join-Path -Path $Env:CONDA_PREFIX -ChildPath share/iCub)"
    $Env:ROS_PACKAGE_PATH+=";$(Join-Path -Path $Env:CONDA_PREFIX -ChildPath share)"
    $Env:AMENT_PREFIX_PATH+=";$Env:CONDA_PREFIX"
}


if (Test-Path env:COMSPEC) {
    $Env:GAZEBO_MODEL_PATH+=";$(Join-Path -Path $Env:CONDA_PREFIX -ChildPath Library\share\iCub\robots)"
}
else {
    $Env:GAZEBO_MODEL_PATH+=";$(Join-Path -Path $Env:CONDA_PREFIX -ChildPath share/iCub/robots)"
}


if (Test-Path env:COMSPEC) {
    $Env:GAZEBO_MODEL_PATH+=";$(Join-Path -Path $Env:CONDA_PREFIX -ChildPath Library\share)"
}
else {
    $Env:GAZEBO_MODEL_PATH+=";$(Join-Path -Path $Env:CONDA_PREFIX -ChildPath share)"
}

